@@ -6,6 +6,7 @@ from pandas.tseries.offsets import YearBegin, YearEnd
 import pytz
 import requests
 from bs4 import BeautifulSoup
+from bs4.builder import XMLParsedAsHTMLWarning
 
 from entsoe.exceptions import InvalidPSRTypeError, InvalidBusinessParameterError
 from .exceptions import NoMatchingDataError, PaginationError
@@ -16,13 +17,16 @@ from .parsers import parse_prices, parse_loads, parse_generation, \
     parse_imbalance_volumes_zip, parse_netpositions, parse_procured_balancing_capacity, \
     parse_water_hydro
 from .decorators import retry, paginated, year_limited, day_limited, documents_limited
+import warnings
+
+warnings.filterwarnings('ignore', category=XMLParsedAsHTMLWarning)
 
 __title__ = "entsoe-py"
-__version__ = "0.5.4"
+__version__ = "0.5.5"
 __author__ = "EnergieID.be, Frank Boerman"
 __license__ = "MIT"
 
-URL = 'https://transparency.entsoe.eu/api'
+URL = 'https://web-api.tp.entsoe.eu/api'
 
 
 class EntsoeRawClient:
@@ -1060,7 +1064,10 @@ class EntsoePandasClient(EntsoeRawClient):
         """
         area = lookup_area(country_code)
         text = super(EntsoePandasClient, self).query_day_ahead_prices(
-            country_code=area, start=start, end=end)
+            country_code=area,
+            start=start-pd.Timedelta(days=1),
+            end=end+pd.Timedelta(days=1)
+        )
         series = parse_prices(text)
         series = series.tz_convert(area.tz)
         series = series.truncate(before=start, after=end)
@@ -1513,9 +1520,12 @@ class EntsoePandasClient(EntsoeRawClient):
     @paginated
     @documents_limited(100)
     def query_offered_capacity(
-            self, country_code_from: Union[Area, str],
-            country_code_to: Union[Area, str], start: pd.Timestamp,
-            end: pd.Timestamp, contract_marketagreement_type: str,
+            self,
+            country_code_from: Union[Area, str],
+            country_code_to: Union[Area, str],
+            contract_marketagreement_type: str,
+            start: pd.Timestamp,
+            end: pd.Timestamp,
             implicit: bool = True, offset: int = 0, **kwargs) -> pd.Series:
         """
         Allocated result documents, for OC evolution see query_intraday_offered_capacity
@@ -1525,10 +1535,10 @@ class EntsoePandasClient(EntsoeRawClient):
         ----------
         country_code_from : Area|str
         country_code_to : Area|str
-        start : pd.Timestamp
-        end : pd.Timestamp
         contract_marketagreement_type : str
             type of contract (see mappings.MARKETAGREEMENTTYPE)
+        start : pd.Timestamp
+        end : pd.Timestamp
         implicit: bool (True = implicit - default for most borders. False = explicit - for instance BE-GB)
         offset: int
             offset for querying more than 100 documents
@@ -1604,18 +1614,21 @@ class EntsoePandasClient(EntsoeRawClient):
     @year_limited
     @paginated
     def query_procured_balancing_capacity(
-            self, country_code: Union[Area, str], start: pd.Timestamp,
-            end: pd.Timestamp, process_type: str,
+            self,
+            country_code: Union[Area, str],
+            process_type: str,
+            start: pd.Timestamp,
+            end: pd.Timestamp,
             type_marketagreement_type: Optional[str] = None) -> bytes:
         """
         Activated Balancing Energy [17.1.E]
         Parameters
         ----------
         country_code : Area|str
-        start : pd.Timestamp
-        end : pd.Timestamp
         process_type : str
             A51 ... aFRR; A47 ... mFRR
+        start : pd.Timestamp
+        end : pd.Timestamp
         type_marketagreement_type : str
             type of contract (see mappings.MARKETAGREEMENTTYPE)
 
@@ -1666,18 +1679,21 @@ class EntsoePandasClient(EntsoeRawClient):
     @paginated
     @documents_limited(100)
     def query_contracted_reserve_prices(
-            self, country_code: Union[Area, str], start: pd.Timestamp,
-            end: pd.Timestamp, type_marketagreement_type: str,
+            self,
+            country_code: Union[Area, str],
+            type_marketagreement_type: str,
+            start: pd.Timestamp,
+            end: pd.Timestamp,
             psr_type: Optional[str] = None,
             offset: int = 0) -> pd.DataFrame:
         """
         Parameters
         ----------
         country_code : Area, str
-        start : pd.Timestamp
-        end : pd.Timestamp
         type_marketagreement_type : str
             type of contract (see mappings.MARKETAGREEMENTTYPE)
+        start : pd.Timestamp
+        end : pd.Timestamp
         psr_type : str
             filter query for a specific psr type
         offset : int
@@ -1701,18 +1717,21 @@ class EntsoePandasClient(EntsoeRawClient):
     @paginated
     @documents_limited(100)
     def query_contracted_reserve_amount(
-            self, country_code: Union[Area, str], start: pd.Timestamp,
-            end: pd.Timestamp, type_marketagreement_type: str,
+            self,
+            country_code: Union[Area, str],
+            type_marketagreement_type: str,
+            start: pd.Timestamp,
+            end: pd.Timestamp,
             psr_type: Optional[str] = None,
             offset: int = 0) -> pd.DataFrame:
         """
         Parameters
         ----------
         country_code : Area|str
-        start : pd.Timestamp
-        end : pd.Timestamp
         type_marketagreement_type : str
             type of contract (see mappings.MARKETAGREEMENTTYPE)
+        start : pd.Timestamp
+        end : pd.Timestamp
         psr_type : str
             filter query for a specific psr type
         offset : int
@@ -1907,7 +1926,7 @@ class EntsoePandasClient(EntsoeRawClient):
         df = df.tz_convert(area.tz)
         # Truncation will fail if data is not sorted along the index in rare
         # cases. Ensure the dataframe is sorted:
-        df = df.sort_index(0)
+        df = df.sort_index(axis=0)
         df = df.truncate(before=start, after=end)
         return df
 
@@ -1942,14 +1961,14 @@ class EntsoePandasClient(EntsoeRawClient):
             end: pd.Timestamp) -> pd.DataFrame:
         """Query the combination of both domestic generation and imports"""
         generation = self.query_generation(country_code=country_code, end=end,
-                                           start=start, lookup_bzones=True)
+                                           start=start, nett=True)
         generation = generation.loc[:, (generation != 0).any(
             axis=0)]  # drop columns that contain only zero's
-        generation = generation.resample('H').sum()
         imports = self.query_import(country_code=country_code, start=start,
                                     end=end)
 
         data = {f'Generation': generation, f'Import': imports}
         df = pd.concat(data.values(), axis=1, keys=data.keys())
+        df = df.ffill()
         df = df.truncate(before=start, after=end)
         return df
